@@ -13,7 +13,7 @@ import numpy as np
 
 import os
 
-from .util import ensure_3args
+from .util import _ensure_4args, _default
 from .plotting import plot_result, plot_phase_plane
 
 
@@ -37,8 +37,10 @@ class OdeSys(object):
     ----------
     f: callback
         first derivatives of dependent variables (y) with respect to
-        dependent variable (x). Signature rhs(x, y[:]) --> f[:] or
-        rhs(x, y[:], p[:]) --> f[:] or
+        dependent variable (x). Signature is any of:
+            - rhs(x, y[:]) --> f[:]
+            - rhs(x, y[:], p[:]) --> f[:]
+            - rhs(x, y[:], p[:], backend=math) --> f[:]
     jac: callback
         Jacobian matrix (dfdy). Required for implicit methods.
     dfdx: callback
@@ -61,6 +63,8 @@ class OdeSys(object):
         for evaluating the vector of derivatives
     j_cb : callback
         for evaluating the Jacobian matrix of f
+    roots_cb : callback
+    nroots : int
     names : iterable of strings
     internal_xout : 1D array of floats
         internal values of dependent variable before post-processing
@@ -69,6 +73,7 @@ class OdeSys(object):
     internal_params : 1D array of floats
         internal parameter values before post-processing
 
+
     Examples
     --------
     >>> odesys = OdeSys(lambda x, y, p: p[0]*x + p[1]*y[0]*y[0])
@@ -86,8 +91,8 @@ class OdeSys(object):
     def __init__(self, f, jac=None, dfdx=None, roots=None, nroots=None,
                  band=None, names=None, pre_processors=None,
                  post_processors=None):
-        self.f_cb = ensure_3args(f)
-        self.j_cb = ensure_3args(jac) if jac is not None else None
+        self.f_cb = _ensure_4args(f)
+        self.j_cb = _ensure_4args(jac) if jac is not None else None
         self.dfdx_cb = dfdx
         self.roots_cb = roots
         self.nroots = nroots
@@ -215,6 +220,9 @@ class OdeSys(object):
         """
         intern_xout, intern_y0, self.internal_params = self.pre_process(
             xout, y0, params)
+        if hasattr(self, 'ny'):
+            if len(intern_y0) != self.ny:
+                raise ValueError("Incorrect length of intern_y0")
         integrator = kwargs.pop('integrator', None)
         if integrator is None:
             integrator = os.environ.get('PYODESYS_INTEGRATOR', 'scipy')
@@ -453,13 +461,10 @@ set_integrator.html#scipy.integrate.ode.set_integrator>`_
 
         if 'names' not in kwargs:
             kwargs['names'] = getattr(self, 'names', None)
-        if (internal_xout, internal_yout, internal_params) == (None,)*3:
-            internal_xout = self.internal_xout
-            internal_yout = self.internal_yout
-            internal_params = self.internal_params
-        elif None in (internal_xout, internal_yout, internal_params):
-            raise ValueError("Pass either all or none of internal_* kwargs")
-        return cb(internal_xout, internal_yout, internal_params, **kwargs)
+
+        return cb(_default(internal_xout, self.internal_xout),
+                  _default(internal_yout, self.internal_yout),
+                  _default(internal_params, self.internal_params), **kwargs)
 
     def plot_result(self, **kwargs):
         """ Plots the integrated dependent variables from last integration.
@@ -484,9 +489,11 @@ set_integrator.html#scipy.integrate.ode.set_integrator>`_
         """ Running stiffness ratio from last integration.
 
         Calculate sittness ratio, i.e. the ratio between the largest and
-        smallest absolute eigenvalue of the jacobian matrix (from SVD).
-        Note that this is a very expensive method for any but the smallest
-        systems.
+        smallest absolute eigenvalue of the jacobian matrix. The user may
+        supply their own routine for calculating the eigenvalues, or they
+        will be calculated from the SVD (singular value decomposition).
+        Note that calculating the SVD for any but the smallest Jacobians may
+        prove to be prohibitively expensive.
 
         Parameters
         ----------
@@ -494,7 +501,8 @@ set_integrator.html#scipy.integrate.ode.set_integrator>`_
             internal_xout, internal_yout, internal_params, taken
             from last integration if not specified.
         eigenvals_cb: callback (optional)
-            signature (x, y, p) (internal variables)
+            signature (x, y, p) (internal variables), when not provided an
+            internal routine will use ``self.j_cb`` and ``scipy.linalg.svd``.
 
         """
         if eigenvals_cb is None:
